Module launch_entry

Module launch_entry 

Structs

LaunchEntry
Represents an item that can be launched in the item list

Traits

LaunchAction
LaunchId
Trait for items that can be launched and have an identifier
Launchable