Module launch_entry
free_
launch
0.2.3
Module launch_
entry
Module Items
Structs
Traits
In crate free_
launch
free_launch
Module
launch_
entry
Structs

Launch
Entry
Represents an item that can be launched in the item list
Traits

Launch
Action
Launch
Id
Trait for items that can be launched and have an identifier
Launchable